Struct OrRetryPolicyFn

pub struct OrRetryPolicyFn<P = RateLimitRetryPolicy> { /* private fields */ }
A RetryPolicy that supports an additional closure for deciding if an error should be retried.

Implementations

Source

impl<P> OrRetryPolicyFn<P>

pub fn new<F>(base: P, or: F) -> Self
where F: Fn(&TransportError) -> bool + Send + Sync + 'static,

Creates a new instance with the given base policy and the given closure