Struct RateLimitRetryPolicy

#[non_exhaustive]
pub struct RateLimitRetryPolicy;
RateLimitRetryPolicy implements RetryPolicy to determine whether to retry depending on the err.

Implementations

Source

impl RateLimitRetryPolicy

pub fn or<F>(self, f: F) -> OrRetryPolicyFn<Self>
where F: Fn(&TransportError) -> bool + Send + Sync + 'static,

Creates a new RetryPolicy that in addition to this policy respects the given closure function for detecting if an error should be retried.